import React, { Component, useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Table, Avatar, Radio, Modal, Descriptions } from 'antd';
import moment from 'moment';
import EChart from '../../../../components/EchartsTest/EChart';
import NewUsers from './NewUsers'
import style from './style.less';
import request from '../../../../utils/request';
import apis from '../../../../services/apis';
import router from 'umi/router';
import AuthButton from '@/components/AuthButton';
import BuildingSelect from '@/components/SelectButton/BuildSelect';


const { RangePicker } = DatePicker;
const { Option } = Select

const formItemLayout = {
    labelCol: { span: 10},
    wrapperCol: { span: 14 },
  };
  
let daterange = []
let tableTitle = ['类型']

let columns = [
  {
    title: '日期',
    dataIndex: 'createTime',
    key: 'createTime',
  },
  {
    title: '分享人数',
    dataIndex: 'sharePersonNum',
    key: 'sharePersonNum',
  },
  {
    title: '分享次数',
    dataIndex: 'shareNum',
    key: 'shareNum',
  },
  {
    title: '访问人数',
    dataIndex: 'visitPersonNum',
    key: 'visitPersonNum',
  },
  {
    title: '访问次数',
    dataIndex: 'visitNum',
    key: 'visitNum',
  },
  {
    title: '新增注册用户',
    dataIndex: 'addRegistNum',
    key: 'addRegistNum',
  },
]


class OverView extends React.Component {

  constructor(props) {
    super(props)
    this.state = {
      personData: [],  
      dataSoures: [],
      tableData: [],
      userType: 'all',
      endDate: '',
      startDate: '',
      buildingId: [],
      targetType: []
    }
  }

  componentDidMount() {
    this.getList()
  }

  getList (params) {
    console.log("params",params);
    request({ ...apis.activityDataStatis.total, params: { ...params } }).then(res => {
      this.setState({ personData: res })
    }).catch(err => {
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  formatDate = (start, end) => {
    const tempStartDate = `${moment(start).format('YYYY-MM-DDT00:00:00.000')}Z`
    const tempEndDate = `${moment(end).format('YYYY-MM-DDT23:59:59.999')}Z`
    return { startDate: tempStartDate, endDate: tempEndDate }
  }

  onChangetime = (_dates, dateStrings) => {
    daterange[1] = dateStrings[1]
    daterange[0] = dateStrings[0]
  }

  handleSubmit = (e, props) => {
    console.log(this.props.form.getFieldValue("startDate"), 'eeeeeee')
    let startDate = null
    let endDate = null
    const buildingId = this.props.form.getFieldValue("buildingId");
    const targetType = this.props.form.getFieldValue("targetType");
    if (this.props.form.getFieldValue("startDate") != undefined){
      startDate = this.props.form.getFieldValue("startDate").toDate()
    }
    if (this.props.form.getFieldValue("endDate") != undefined){
      endDate = this.props.form.getFieldValue("endDate").toDate()
    }
    e.preventDefault();
    props.form.validateFields((err, values) => {
        if (!err) {
          this.getList({buildingId: buildingId, targetType: targetType, startDate: startDate, endDate: endDate})
        }
      });
    this.setState({ startDate: startDate, endDate: endDate, buildingId: this.props.form.getFieldValue("buildingId"), targetType: this.props.form.getFieldValue("targetType") })
  }

  //重置搜索
  handleReset = e => {
    this.props.form.resetFields()
  }

  getDataOf = (days) => {
    console.log(77777777)
    this.setState({ endDate: new Date(), startDate: moment().subtract(days, 'day').toDate() })
    this.getList({ endDate: new Date(), startDate: moment().subtract(days, 'day').toDate() })
  }

  datalist = () => {
    this.setState({ 
      endDate: daterange[1] === '' ? new Date() : daterange[1],
      startDate: daterange[0] === '' ? moment().subtract(7, 'day').toDate() : daterange[0],
    })
  }

  onSuccess = e => {
    this.setState({ dataSoures: e }, () => {
      this.onTabledatas(e)
    })
  }

  onTabledatas = (e) => {
    console.log('this.state.userType: ', this.state.userType)
    e.tdWxDicts.map(x => {
        columns = columns.filter(y => y.key != x.sceneType).concat({
          title: x.sceneAlias,
          dataIndex: x.sceneType,
          key: x.sceneType,
        })
    })
    const data = (e.list || []).reduce((acc, item) => {
      const { sceneType, fromNum, registeredNum, createTime } = item
      const num = this.state.userType === 'registered' ? registeredNum : fromNum
      acc[createTime] = { ...acc[createTime], ...item, [`${sceneType}`]: !num ? 0 : num }
      return acc
    }, {})

    const dictData =  e.tdWxDicts.reduce((acc,item,index) => {
      const { sceneType } = item
      acc[sceneType] = 0
      return acc
    },{})

    const tableData = Object.keys(data).map(k => data[k]).reduce((acc,item,index) => {
      acc[index] = { ...dictData, ...item }
      return acc
    },[])

    this.setState({ tableData })

  }

  handleSelectChange = (e) => {
    this.setState({ userType: e }, () => {
      this.onTabledatas(this.state.dataSoures)
    })
  }


  render() {
    const { getFieldDecorator } = this.props.form;

    return (
    <>
      <div style={{
        backgroundColor: '#fff',
        padding: '32PX 28px',
        boxShadow: '0px 0px 16px 2px rgba(0,0,0,0.12)',
        borderRadius: '12px',
        minHeight: '60vh'
      }}>
        <Radio.Group buttonStyle="solid" defaultValue="a">
          <Radio.Button value="c" onClick={() => this.getDataOf(1)}>今日</Radio.Button>
          <Radio.Button value="a" onClick={() => this.getDataOf(7)}>最近7天</Radio.Button>
          <Radio.Button value="b" onClick={() => this.getDataOf(30)}>最近1月</Radio.Button>
        </Radio.Group>
        <Form layout="inline" onSubmit={e => this.handleSubmit(e, this.props)}>
            <Form.Item style={{marginTop:'20px', marginBottom:'20px'}}>
            {getFieldDecorator('startDate')(
                <DatePicker placeholder="开始日期"/>,
            )}
            </Form.Item>
            <Form.Item style={{marginTop:'20px', marginBottom:'20px'}}>
            {getFieldDecorator('endDate')(
                <DatePicker placeholder="结束日期"/>,
            )}
            </Form.Item>
          <Form.Item style={{marginTop:'20px', marginBottom:'20px'}}>
              {getFieldDecorator('buildingId')(<BuildingSelect />)}
          </Form.Item>
          <Form.Item style={{marginTop:'20px', marginBottom:'20px'}}>
            {getFieldDecorator('targetType')(
                <Select placeholder="活动类型" style={{ width: 150, marginLeft:'20px'  }}>
                <Option value="activity">报名活动</Option>
                <Option value="help">助力活动</Option>
                <Option value="group">拼团活动</Option>
                <Option value="h5">H5活动</Option>
                <Option value="live">直播</Option>
            </Select>
            )}
          </Form.Item>
          <Form.Item style={{marginTop:'20px', marginBottom:'20px'}}>
            <Button type="primary" htmlType="submit" style={{ marginLeft: '30px' }}>
                查询
            </Button>
            <Button onClick={e => this.handleReset()} style={{ marginLeft: '30px' }}>重置</Button>
          </Form.Item>
          </Form>     
        <div>

            <div style={{ display: 'flex', marginBottom: '33px' }}>
            <div style={{
                textAlign: 'center', display: 'flex', justifyContent: 'center', lineHeight: '100px', background: 'linear-gradient(144deg,rgba(255,126,74,1) 0%,rgba(255,196,168,1) 100%)', height: '100px',
                boxShadow: '0px  0.106rem 14px -15px rgba(255,126,74,1)',
                borderRadius: '12px', width: '32%', marginRight: '2%'
            }}>
                <span style={{ fontSize: '24px', color: '#fff' }}>分享总次数 </span>
                <span style={{ fontSize: '52px', color: '#fff', marginLeft: '26px', fontFamily: 'fantasy' }}>{ this.state.personData.sharePersonNum || '0'}</span>
            </div>
            <div style={{
                textAlign: 'center', display: 'flex', justifyContent: 'center', lineHeight: '100px', background: 'linear-gradient(144deg,rgba(255,126,74,1) 0%,rgba(255,196,168,1) 100%)', height: '100px',
                boxShadow: '0px  0.106rem 14px -15px rgba(255,126,74,1)',
                borderRadius: '12px', width: '32%', marginRight: '2%'
            }}>
                <span style={{ fontSize: '24px', color: '#fff' }}>分享总人数 </span>
                <span style={{ fontSize: '52px', color: '#fff', marginLeft: '26px', fontFamily: 'fantasy' }}>{ this.state.personData.shareNum || '0'}</span>
            </div>
            <div style={{
                textAlign: 'center', display: 'flex', justifyContent: 'center', lineHeight: '100px', background: 'linear-gradient(144deg,rgba(255,126,74,1) 0%,rgba(255,196,168,1) 100%)', height: '100px',
                boxShadow: '0px  0.106rem 14px -15px rgba(255,126,74,1)',
                borderRadius: '12px', width: '32%', marginRight: '2%'
            }}>
                <span style={{ fontSize: '24px', color: '#fff' }}>访问总次数 </span>
                <span style={{ fontSize: '52px', color: '#fff', marginLeft: '26px', fontFamily: 'fantasy' }}>{ this.state.personData.visitPersonNum || '0'}</span>
            </div>
            <div style={{
                textAlign: 'center', display: 'flex', justifyContent: 'center', lineHeight: '100px', background: 'linear-gradient(144deg,rgba(255,126,74,1) 0%,rgba(255,196,168,1) 100%)', height: '100px',
                boxShadow: '0px  0.106rem 14px -15px rgba(255,126,74,1)',
                borderRadius: '12px', width: '32%', marginRight: '2%'
            }}>
                <span style={{ fontSize: '24px', color: '#fff' }}>访问总人数 </span>
                <span style={{ fontSize: '52px', color: '#fff', marginLeft: '26px', fontFamily: 'fantasy' }}>{ this.state.personData.visitNum || '0'}</span>
            </div>
            </div>
          
            <div style={{ display: 'flex' }}>
                <div className={style.bar}>
                    <NewUsers startDate={this.state.startDate} endDate={this.state.endDate} buildingId={this.state.buildingId} targetType={this.state.targetType} dataZoom={false}></NewUsers>
                </div>
            </div >
            <AuthButton name="admin.customer.import" noRight={null}>
            <Button type="primary" style={{ float: 'right', margin: '20px 0', zIndex: 1 }}>
                导出
            </Button>
            </AuthButton>
          <Table style={{marginTop:'20px'}} dataSource={this.state.tableData} columns={columns} pagination={false} scroll={{ y: 500 }}></Table>
        </div>
      </div>
    </>
    )
    
  }
}
const WrappedTypeForm = Form.create()(OverView);
export default WrappedTypeForm
